@@ -120,6 +120,7 @@ class Form(object):
     def __init__(self, classes=[], **attrs):
         self.classes = classes
         self.attrs = attrs
+        self.attrs['method'] = 'POST'
         self.fields = []
         self.btns = []
 
@@ -136,13 +137,14 @@ class Form(object):
         help: field-help
         """
         assert bool(input), 'input must be Tag object'
-        label = label + ' *' if 'required' in input.nv_attributes else label
         field_box = tf.DIV(Class="field")
-        field_box.label_box = tf.DIV()
+        field_box.label_box = tf.DIV(Class='field-label')
         if label:
-            field_box.label_box.label = tf.LABEL(label, Class='field-label', For=input.attributes['id'])
-        field_box.input = input
-        input.add_classes(['field-input'])
+            field_box.label_box.label = tf.LABEL(label, For=input.attributes['id'])
+        field_box.input_box = tf.DIV(Class="field-input")
+        field_box.input_box.input = input
+        if 'required' in input.nv_attributes:
+            field_box.input_box.c = tf.C('*')
         if fhelp:
             field_box.fhelp = tf.SPAN(fhelp, Class='field-help')
         self.fields.append(field_box)
